<?php

/**
 * Provide a public-facing view for the plugin
 *
 * This file is used to markup the public-facing aspects of the plugin.
 *
 * @link       https://www.biuro.lt
 * @since      1.0.0
 *
 * @package    Biuro_Contacts
 * @subpackage Biuro_Contacts/public/partials
 */

/**
 * @link https://codex.wordpress.org/Creating_Options_Pages
 * @link https://www.smashingmagazine.com/2016/04/three-approaches-to-adding-configurable-fields-to-your-plugin/
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) die;
?>

<?php
    $nameValue = isset($_SESSION['employees--name-value']) ? $_SESSION['employees--name-value'] : '';
    $nameStatus = isset($_SESSION['employees--name-status']) ? $_SESSION['employees--name-status'] : '';
    $nameMsg = isset($_SESSION['employees--name-message']) ? $_SESSION['employees--name-message'] : '';
    $nameMessage = __($nameMsg, 'biuro-contacts');

    $phoneValue = isset($_SESSION['employees--phone-value']) ? $_SESSION['employees--phone-value'] : '';
    $phoneStatus = isset($_SESSION['employees--phone-status']) ? $_SESSION['employees--phone-status'] : '';
    $phoneMsg = isset($_SESSION['employees--phone-message']) ? $_SESSION['employees--phone-message'] : '';
    $phoneMessage = __($phoneMsg, 'biuro-contacts');

    $emailValue = isset($_SESSION['employees--email-value']) ? $_SESSION['employees--email-value'] : '';
    $emailStatus = isset($_SESSION['employees--email-status']) ? $_SESSION['employees--email-status'] : '';
    $emailMsg = isset($_SESSION['employees--email-message']) ? $_SESSION['employees--email-message'] : '';
    $emailMessage = __($emailMsg, 'biuro-contacts');
?>
    <div class="c-form--row">
        <label class="c-form--label" for="form-name"><?php _e('Name, surname', 'biuro-contacts'); ?></label>
        <div class="c-form--input-wrap <?php if ($nameStatus) { echo "c-form--input-wrap--$nameStatus"; } ?>">
            <input type="text" class="c-form--input" id="form-name" name="name" value="<?php echo $nameValue; ?>" <?php if ($nameStatus == 'error'): ?> autofocus="autofocus" <?php endif; ?>>
        </div>
        <?php if ($nameMessage): ?>
            <div class="c-form--validation c-form--validation-<?php echo $nameStatus; ?>">
                <?php echo $nameMessage; ?>
            </div>
        <?php endif; ?>
    </div><!-- .c-form--row -->

    <div class="c-form--row">
        <label class="c-form--label" for="form-phone"><?php _e('Phone no.', 'biuro-contacts'); ?></label>
        <div class="c-form--input-wrap <?php if ($phoneStatus) { echo "c-form--input-wrap--$phoneStatus"; } ?>">
            <input type="tel" class="c-form--input" id="form-phone" name="phone" value="<?php echo $phoneValue; ?>" <?php if ($nameStatus != 'error' && $phoneStatus == 'error'): ?> autofocus="autofocus" <?php endif; ?>>
        </div>
        <?php if ($phoneMessage): ?>
            <div class="c-form--validation c-form--validation-<?php echo $phoneStatus; ?>">
                <?php echo $phoneMessage; ?>
            </div>
        <?php endif; ?>
    </div><!-- .c-form--row -->

    <div id="agree"></div>

    <div class="c-form--row">
        <label class="c-form--label" for="form-email"><?php _e('Email address', 'biuro-contacts'); ?></label>
        <div class="c-form--input-wrap <?php if ($emailStatus) { echo "c-form--input-wrap--$emailStatus"; } ?>">
                <input type="email" class="c-form--input" id="form-email" name="email" value="<?php echo $emailValue; ?>">
        </div>
        <?php if ($emailMessage): ?>
            <div class="c-form--validation c-form--validation-<?php echo $emailStatus; ?>">
                <?php echo $emailMessage; ?>
            </div>
        <?php endif; ?>
    </div><!-- .c-form--row -->

    <div class="c-form--row">
        <div class="c-form--submit-wrap">
<?php
    if (isset($attr['page']) && ($attr['page'] == 'landing-1' || $attr['page'] == 'landing-2' || $attr['page'] == 'landing-3' || $attr['page'] == 'landing-4')):
?>
        <button type="submit" class="o-btn c-btn--main c-btn--fill" name="s" value="1"><?php _e('Get a job offer', 'biuro'); ?></button>
<?php
    else:
?>
        <button type="submit" class="o-btn c-btn--main c-btn--fill" name="s" value="1"><?php _e('Submit', 'biuro-contacts'); ?></button>
<?php
    endif;
?>
        </div>
    </div><!-- .c-form--row -->

<?php
/*
    <div class="c-form--row">
        <div class="c-form--checkbox-wrap">
            <input id="form-agree" type="checkbox" class="c-form--checkbox <?php if ($agreeStatus) { echo "c-form--checkbox--$agreeStatus"; } ?>" name="agree" value="1" <?php if ($agreeValue): ?> checked="checked"<?php endif; ?> <?php if ($nameStatus != 'error' && $phoneStatus != 'error' && $agreeStatus == 'error'): ?> autofocus="autofocus" <?php endif; ?> >
            <label class="c-form--label-checkbox" for="form-agree"><?php _e('I agree, that my personal data will be used for offering me a job. For more detailed information view our <a href="https://biuro.eu/privacy-en.html" target="_blank" rel="noopener">Personal Data Protection Policy.</a>', 'biuro-contacts'); ?></label>
        </div>
        <?php if ($agreeMessage): ?>
            <div class="c-form--validation c-form--validation-<?php echo $agreeStatus; ?>">
                <?php echo $agreeMessage; ?>
            </div>
        <?php endif; ?>
    </div><!-- .c-form--row -->
*/
?>

    <div class="c-form--row">
        <div class="c-form--label-infobox">
            <?php _e('We process your personal data to offer you jobs. More information at <a href="https://biuro.eu/privacy-en.html" target="_blank" rel="noopener">Personal Data Protection Policy.</a>', 'biuro-contacts'); ?>
            <br />
            <?php _e('This site is protected by reCAPTCHA and the Google <a href="https://policies.google.com/privacy">Privacy Policy</a> and <a href="https://policies.google.com/terms">Terms of Service</a> apply.', 'biuro-contacts'); ?>
            <input type="hidden" name="agree" value="1">
        </div>
    </div><!-- .c-form--row -->
